# PISA Examples

Feel free to go through the Jupyter notebooks in this directory containing various examples and tutorials.

An example IceCube oscillation analysis is provided in the corresponding [Jupyter notebook](IceCube_3y_oscillations_example.ipynb).
